import { Collection, CollectionStream, EntitySubject, IdInterface, JSONEntity, ServerMessageEntity } from '../index';
import { ClassType } from '@deepkit/core';
import { Subject } from 'rxjs';
declare class EntitySubjectStore<T extends IdInterface> {
    subjects: {
        [id: string]: EntitySubject<T>;
    };
    consumers: {
        [id: string]: {
            count: number;
        };
    };
    forkUnsubscribed(id: string | number): Promise<void>;
    /**
     *  If we would return the original EntitySubject and one of the consumers unsubscribes()
     *  it would unsubscribe for ALL subscribers of that particular entity item.
     *  so we fork it. The fork can be unsubscribed without touching the origin.
     */
    createFork(id: string | number, item?: T): EntitySubject<T>;
    getEntitySubjectCount(): number;
    getForkCount(id: string | number): number;
    protected getOrCreateSubject(id: string | number, item?: T): EntitySubject<T>;
    getItem(id: string | number): T;
    removeItemAndNotifyObservers(id: string | number): void;
    notifyForks(id: string | number): void;
    notifyForksAboutPatches(id: string | number, patches: {
        [path: string]: any;
    }): void;
    setItemAndNotifyForks(id: string | number, item: T): void;
    hasStoreItem(id: string | number): boolean;
}
export declare class EntityState {
    readonly deleted: Subject<IdInterface>;
    private readonly items;
    clear(): void;
    getStore<T extends IdInterface>(classType: ClassType<T>): EntitySubjectStore<T>;
    handleEntityMessage<T extends IdInterface>(stream: ServerMessageEntity): void;
    /**
     * Creates the origin EntitySubject and returns a fork from it.
     * Origin will be removed as soon as all forks have unsubscribed.
     *
     * @param classType
     * @param jsonItem
     */
    handleEntity<T extends IdInterface>(classType: ClassType<T>, jsonItem: JSONEntity<T>): EntitySubject<T>;
    handleCollectionNext<T extends IdInterface>(collection: Collection<T>, stream: CollectionStream): void;
}
export {};
